==> parser-1.8.1-sources.jar: org/verapdf/pd/font/truetype/TrueTypeHheaTable.java <==
/**
 * This file is part of veraPDF Parser, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Parser is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Parser as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Parser as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.pd.font.truetype;

import org.verapdf.io.SeekableInputStream;

import java.io.IOException;

/**
 * This class does parsing of True Type "hhea" table and extracts all the data
 * needed.
 *
 * @author Sergey Shemyakov
 */
class TrueTypeHheaTable extends TrueTypeTable {

    private int numberOfHMetrics;

    TrueTypeHheaTable(SeekableInputStream source, long offset) {
        super(source, offset);
    }

    @Override
    void readTable() throws IOException {
        long startingOffset = this.source.getOffset();
        this.source.seek(this.offset);
        this.source.skip(4 +   // version
                2 +             // ascender
                2 +             // descender
                2 +             // line gap
                2 +             // advanceWidthMax
                2 +             // minLeftSideBearing
                2 +             // minRightSideBearing
                2 +             // xMaxExtent
                2 +             // caretSlopeRise
                2 +             // caretSlopeRun
                10 +            // reserved
                2               // metricDataFormat
        );
        this.numberOfHMetrics = this.readUShort();
        this.source.seek(startingOffset);
    }

    int getNumberOfHMetrics() {
        return numberOfHMetrics;
    }
}

==> parser-1.26.1-sources.jar: org/verapdf/pd/font/truetype/TrueTypeHheaTable.java <==
/**
 * This file is part of veraPDF Parser, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Parser is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Parser as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Parser as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.pd.font.truetype;

import org.verapdf.io.SeekableInputStream;

import java.io.IOException;

/**
 * This class does parsing of True Type "hhea" table and extracts all the data
 * needed.
 *
 * @author Sergey Shemyakov
 */
class TrueTypeHheaTable extends TrueTypeTable {

    private int numberOfHMetrics;
    private int ascender;
    private int descender;

    TrueTypeHheaTable(SeekableInputStream source, long offset) {
        super(source, offset);
    }

    @Override
    void readTable() throws IOException {
        long startingOffset = this.source.getOffset();
        this.source.seek(this.offset);
        this.source.skip(4); // version
        this.ascender = this.readFWord();
        this.descender = this.readFWord();
        this.source.skip(2 + // line gap
                2 +             // advanceWidthMax
                2 +             // minLeftSideBearing
                2 +             // minRightSideBearing
                2 +             // xMaxExtent
                2 +             // caretSlopeRise
                2 +             // caretSlopeRun
                10 +            // reserved
                2               // metricDataFormat
        );
        this.numberOfHMetrics = this.readUShort();
        this.source.seek(startingOffset);
    }

    int getNumberOfHMetrics() {
        return numberOfHMetrics;
    }

    public int getAscender() {
        return ascender;
    }

    public int getDescender() {
        return descender;
    }
}
